math

package module
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2025 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package math provides a functions for general math operations. Implements the solution required by the Learning Go book.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Add

func Add(n, m int) int

Add takes two numbers and adds them together. More information can be found at MathIsFun.

Types

This section is empty.

Jump to